==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/es.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Tema de alto contraste",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tema de alto contraste para facilitar la navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
    "Dark theme (beta)" : "Tema oscuro (beta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tema oscuro para facilitar la navegación redeciendo el brillo y la luminosidad. Aún se encuentra en desarrollo, por favor comunique cualquier problema que encuentre.",
    "Dyslexia font" : "Tipo de letra para dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra/fuente libre diseñado para mitigar algunos de los errores de lectura comunes causados por la dislexia.",
    "Accessibility" : "Accesibilidad",
    "Accessibility options for nextcloud" : "Opciones de accesibilidad para nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Ofrece múltiples opciones de accesibilidad para facilitarte el uso de Nextcloud",
    "Web Content Accessibility Guidelines" : "Guía de estilo de accesibilidad del contenido web",
    "our issue tracker" : "nuestro rastreador de problemas",
    "our design team" : "nuestro equipo de diseño",
    "Enable" : "Activa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/es.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Tema de alto contraste",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tema de alto contraste para facilitar la navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tema oscuro para facilitar la navegación redeciendo el brillo y la luminosidad. Aún se encuentra en desarrollo, por favor comunique cualquier problema que encuentre.",
    "Dyslexia font" : "Tipo de letra para dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra/fuente libre diseñado para mitigar algunos de los errores de lectura comunes causados por la dislexia.",
    "Accessibility" : "Accesibilidad",
    "Accessibility options for nextcloud" : "Opciones de accesibilidad para nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Ofrece múltiples opciones de accesibilidad para facilitarte el uso de Nextcloud",
    "Web Content Accessibility Guidelines" : "Guía de estilo de accesibilidad del contenido web",
    "our issue tracker" : "nuestro rastreador de problemas",
    "our design team" : "nuestro equipo de diseño",
    "Enable" : "Activa",
    "Dark theme (beta)" : "Tema oscuro (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic es un tipo de letra/fuente libre diseñada para mitigar algunos de los errores de lectura más comunes causados por la dislexia. Este tipo de letra lo creó Abelardo González, que lo liberó con una licencia de código abierto.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Proporciona múltiples opciones de accesibilidad para facilitar el uso de nextcloud",
    "Themes" : "Temas",
    "Fonts" : "Fuentes",
    "enabled" : "activado"
},
"nplurals=2; plural=(n != 1);");
